Crate microagents_events

Crate microagents_events 

Modules

types

Structs

AssistantResponseEvent
Event emitted when the assistant produces a complete response.
SessionInitEvent
Event emitted when a session is initialized.
SessionStopEvent
Event emitted when a session stops.
SkillLoadEvent
Event emitted when a skill is loaded.
StreamDeltaEvent
Event emitted for each delta in a streaming response.
ToolCallEvent
Event emitted when a tool is called.
ToolResultEvent
Event emitted when a tool returns a result.
Usage
UserPromptSubmitEvent
Event emitted when the user submits a prompt.

Enums

AgentEventAny
A sum type wrapping any agent event.
DeltaType
Type of content delta in a stream.
SessionInitType
Indicates whether a session is being started fresh or resumed.

Constants

EVENTS_PROTOCOL_VERSION