Module types

Module types 

Structs

FunctionCall
JsonRpcNotification
A JSON-RPC 2.0 notification message.
ToolCall

Enums

AgentEventError
Errors that can occur when parsing a JsonRpcNotification into an [AgentEventAny].
ToolResult
Result of a tool execution, either success with output or failure with an error message.

Traits

AgentEvent
Trait for events that can be converted to JSON-RPC notifications and carry a session ID.