Modules
Structs
- Assistant
Response Event - Event emitted when the assistant produces a complete response.
- Session
Init Event - Event emitted when a session is initialized.
- Session
Stop Event - Event emitted when a session stops.
- Skill
Load Event - Event emitted when a skill is loaded.
- Stream
Delta Event - Event emitted for each delta in a streaming response.
- Tool
Call Event - Event emitted when a tool is called.
- Tool
Result Event - Event emitted when a tool returns a result.
- Usage
- User
Prompt Submit Event - Event emitted when the user submits a prompt.
Enums
- Agent
Event Any - A sum type wrapping any agent event.
- Delta
Type - Type of content delta in a stream.
- Session
Init Type - Indicates whether a session is being started fresh or resumed.