Structs
- Function
Call - Json
RpcNotification - A JSON-RPC 2.0 notification message.
- Tool
Call
Enums
- Agent
Event Error - Errors that can occur when parsing a
JsonRpcNotificationinto an [AgentEventAny]. - Tool
Result - Result of a tool execution, either success with output or failure with an error message.
Traits
- Agent
Event - Trait for events that can be converted to JSON-RPC notifications and carry a session ID.